import json
import tweepy


def tokens(tokens_file):
    # Get Twitter twitter_tokens
    try:
        f = open(tokens_file, mode='r')
        twitter_tokens = json.load(f)
        f.close()
    except FileNotFoundError as err:
        raise err
    except IOError as err:
        raise err

    return twitter_tokens


def auth(t_tokens):
    # tokens can be found under "Apps > RainBowDashBOT"
    try:
        t_auth = tweepy.OAuthHandler(t_tokens['consumer_api_key'],
                                     t_tokens['consumer_api_key_secret'])

        t_auth.set_access_token(t_tokens['access_token'],
                                t_tokens['access_token_secret'])

        api = tweepy.API(t_auth)

    except Exception as err:
        raise err

    return api


def tweet(api, tweet):
    # post the tweet on twitter
    status = 0

    try:
        if isinstance(tweet, str):
            orig_tweet = api.update_status(status=tweet)
        else:
            # multi-line message - create twitter thread
            orig_tweet = api.update_status(status=tweet[0])
            for i in tweet[1:]:
                reply_tweet = api.update_status(status=i,
                                                in_reply_to_status_id=orig_tweet.id,
                                                auto_populate_reply_metadata=True)
                orig_tweet = reply_tweet

    except tweepy.error.TweepError as err:
        status = 1
        raise err

    return status



import sys

from pyvirtualdisplay import Display
from selenium import webdriver
from selenium.webdriver.chrome.options import Options
from selenium.webdriver.common.keys import Keys
from time import time, ctime, sleep


def init(timer=20):
    wa = {}

    try:
        wa["options"] = Options()
        wa["options"].add_argument("--no-sandbox")
        wa["options"].add_argument("user-data-dir=" + "cookies")

        wa["display"] = Display(visible=0)
        wa["display"].start()

        wa["driver"] = webdriver.Chrome(options=wa["options"])
        wa["driver"].maximize_window()
        wa["driver"].get('https://web.whatsapp.com')
        sleep(timer)
    except Exception as err:
        wa["rc"] = 1
        print(f'Exception occurred in {sys._getframe(2).f_code.co_name} | {err}')

    return wa


def locate_contact(wa, timer=20):
    try:
        wa["driver"].find_element_by_xpath('//*[@title = "{}"]'.format(wa["contact"])).click()
        sleep(timer)
    except Exception as err:
        wa["rc"] = 1
        print(f'Exception occurred in {sys._getframe(2).f_code.co_name} | {err}')

    return wa


def locate_message_box(wa):
    try:
        wa["msg_box"] = wa["driver"].find_element_by_xpath('//*[@id="main"]/footer/div[1]/div[2]/div/div[1]')
    except Exception as err:
        wa["rc"] = 1
        print(f'Exception occurred in {sys._getframe(2).f_code.co_name} | {err}')

    return wa


def send_message(wa, timer=15):
    try:
        # Put the message in one-block
        for i in wa["message"]:
            wa["msg_box"].send_keys(i + Keys.SHIFT + Keys.RETURN)

        wa["msg_box"].send_keys(Keys.ENTER)

        sleep(timer)
    except Exception as err:
        wa["rc"] = 1
        print(f'Exception occurred in {sys._getframe(2).f_code.co_name} | {err}')

    return wa


def close(wa):
    try:
        wa["driver"].quit()
        wa["display"].stop()
    except Exception as err:
        wa["rc"] = 1
        print(f'Exception occurred in {sys._getframe(2).f_code.co_name} | {err}')

    return wa
